@@ -6,20 +6,19 @@ import (
 )
 
 var (
-	knativeUp = prometheus.NewGaugeVec(
+	KnativeUp = prometheus.NewGaugeVec(
 		prometheus.GaugeOpts{
 			Name: "knative_up",
 			Help: "Reports if a Knative component is up",
 		},
 		[]string{"type"},
 	)
-	KnativeServingUpG  = knativeUp.WithLabelValues("serving_status")
-	KnativeEventingUpG = knativeUp.WithLabelValues("eventing_status")
-	//TODO: to be enabled
-	//KnativeKafkaUpG    = knativeUp.WithLabelValues("kafka_status")
+	KnativeServingUpG  prometheus.Gauge
+	KnativeEventingUpG prometheus.Gauge
+	KnativeKafkaUpG    = KnativeUp.WithLabelValues("kafka_status")
 )
 
 func init() {
 	// Register custom metrics with the global prometheus registry
-	metrics.Registry.MustRegister(knativeUp)
+	metrics.Registry.MustRegister(KnativeUp)
 }
