@@ -6,7 +6,6 @@ import (
 	"testing"
 
 	. "github.com/openshift-knative/serverless-operator/knative-operator/pkg/webhook/knativeeventing"
-	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/webhook/testutil"
 	configv1 "github.com/openshift/api/config/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -35,7 +34,7 @@ var ke2 = &eventingv1alpha1.KnativeEventing{
 func TestInvalidNamespace(t *testing.T) {
 	os.Clearenv()
 	os.Setenv("REQUIRED_EVENTING_NAMESPACE", "knative-eventing")
-	validator := KnativeEventingValidator{}
+	validator := Validator{}
 	validator.InjectDecoder(&mockDecoder{ke1})
 	result := validator.Handle(context.TODO(), types.Request{})
 	if result.Response.Allowed {
@@ -43,21 +42,9 @@ func TestInvalidNamespace(t *testing.T) {
 	}
 }
 
-func TestInvalidVersion(t *testing.T) {
-	os.Clearenv()
-	os.Setenv("MIN_OPENSHIFT_VERSION", "4.1.13")
-	validator := KnativeEventingValidator{}
-	validator.InjectDecoder(&mockDecoder{ke1})
-	validator.InjectClient(fake.NewFakeClient(testutil.MockClusterVersion("3.2.0")))
-	result := validator.Handle(context.TODO(), types.Request{})
-	if result.Response.Allowed {
-		t.Error("The version is too low, but the request is allowed")
-	}
-}
-
 func TestLoneliness(t *testing.T) {
 	os.Clearenv()
-	validator := KnativeEventingValidator{}
+	validator := Validator{}
 	validator.InjectDecoder(&mockDecoder{ke1})
 	validator.InjectClient(fake.NewFakeClient(ke2))
 	result := validator.Handle(context.TODO(), types.Request{})
