@@ -7,7 +7,6 @@ import (
 	"os"
 
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/common"
-	webhookutil "github.com/openshift-knative/serverless-operator/knative-operator/pkg/webhook/util"
 	admissionregistrationv1beta1 "k8s.io/api/admissionregistration/v1beta1"
 	servingv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
 	"sigs.k8s.io/controller-runtime/pkg/client"
@@ -28,21 +27,21 @@ func ValidatingWebhook(mgr manager.Manager) (webhook.Webhook, error) {
 		Operations(admissionregistrationv1beta1.Create, admissionregistrationv1beta1.Update).
 		WithManager(mgr).
 		ForType(&servingv1alpha1.KnativeServing{}).
-		Handlers(&KnativeServingValidator{}).
+		Handlers(&Validator{}).
 		Build()
 }
 
-// KnativeServingValidator validates KnativeServing CR's
-type KnativeServingValidator struct {
+// Validator validates KnativeServing CR's
+type Validator struct {
 	client  client.Client
 	decoder types.Decoder
 }
 
 // Implement admission.Handler so the controller can handle admission request.
-var _ admission.Handler = (*KnativeServingValidator)(nil)
+var _ admission.Handler = (*Validator)(nil)
 
 // What makes us a webhook
-func (v *KnativeServingValidator) Handle(ctx context.Context, req types.Request) types.Response {
+func (v *Validator) Handle(ctx context.Context, req types.Request) types.Response {
 	ks := &servingv1alpha1.KnativeServing{}
 
 	err := v.decoder.Decode(req, ks)
@@ -57,12 +56,11 @@ func (v *KnativeServingValidator) Handle(ctx context.Context, req types.Request)
 	return admission.ValidationResponse(allowed, reason)
 }
 
-// KnativeServingValidator checks for a minimum OpenShift version
-func (v *KnativeServingValidator) validate(ctx context.Context, ks *servingv1alpha1.KnativeServing) (allowed bool, reason string, err error) {
+// Validator checks for a minimum OpenShift version
+func (v *Validator) validate(ctx context.Context, ks *servingv1alpha1.KnativeServing) (allowed bool, reason string, err error) {
 	log := common.Log.WithName("validate")
 	stages := []func(context.Context, *servingv1alpha1.KnativeServing) (bool, string, error){
 		v.validateNamespace,
-		v.validateVersion,
 		v.validateLoneliness,
 	}
 	for _, stage := range stages {
@@ -81,33 +79,28 @@ func (v *KnativeServingValidator) validate(ctx context.Context, ks *servingv1alp
 	return
 }
 
-// KnativeServingValidator implements inject.Client.
+// Validator implements inject.Client.
 // A client will be automatically injected.
-var _ inject.Client = (*KnativeServingValidator)(nil)
+var _ inject.Client = (*Validator)(nil)
 
 // InjectClient injects the client.
-func (v *KnativeServingValidator) InjectClient(c client.Client) error {
+func (v *Validator) InjectClient(c client.Client) error {
 	v.client = c
 	return nil
 }
 
-// KnativeServingValidator implements inject.Decoder.
+// Validator implements inject.Decoder.
 // A decoder will be automatically injected.
-var _ inject.Decoder = (*KnativeServingValidator)(nil)
+var _ inject.Decoder = (*Validator)(nil)
 
 // InjectDecoder injects the decoder.
-func (v *KnativeServingValidator) InjectDecoder(d types.Decoder) error {
+func (v *Validator) InjectDecoder(d types.Decoder) error {
 	v.decoder = d
 	return nil
 }
 
-// validate minimum openshift version
-func (v *KnativeServingValidator) validateVersion(ctx context.Context, ks *servingv1alpha1.KnativeServing) (bool, string, error) {
-	return webhookutil.ValidateOpenShiftVersion(ctx, v.client)
-}
-
 // validate required namespace, if any
-func (v *KnativeServingValidator) validateNamespace(ctx context.Context, ks *servingv1alpha1.KnativeServing) (bool, string, error) {
+func (v *Validator) validateNamespace(ctx context.Context, ks *servingv1alpha1.KnativeServing) (bool, string, error) {
 	ns, required := os.LookupEnv("REQUIRED_SERVING_NAMESPACE")
 	if required && ns != ks.Namespace {
 		return false, fmt.Sprintf("KnativeServing may only be created in %s namespace", ns), nil
@@ -116,7 +109,7 @@ func (v *KnativeServingValidator) validateNamespace(ctx context.Context, ks *ser
 }
 
 // validate this is the only KS in this namespace
-func (v *KnativeServingValidator) validateLoneliness(ctx context.Context, ks *servingv1alpha1.KnativeServing) (bool, string, error) {
+func (v *Validator) validateLoneliness(ctx context.Context, ks *servingv1alpha1.KnativeServing) (bool, string, error) {
 	list := &servingv1alpha1.KnativeServingList{}
 	if err := v.client.List(ctx, &client.ListOptions{Namespace: ks.Namespace}, list); err != nil {
 		return false, "Unable to list KnativeServings", err
